#
# spec file for package mojo-executor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mojo-executor
Version:        2.4.0
Release:        3.5
Summary:        Mojo Executor
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://mojo-executor.github.io/mojo-executor/
Source0:        https://github.com/mojo-executor/mojo-executor/archive/refs/tags/mojo-executor-parent-%{version}.tar.gz
Source1:        http://www.apache.org/licenses/LICENSE-2.0
Patch0:         mojo-executor-dependency.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-simple)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
BuildArch:      noarch

%description
The Mojo Executor provides a way to to execute other Mojos (plugins) within a Maven plugin,
allowing to create Maven plugins that are composed of other plugins.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-parent-%{version}
%patch -P 0 -p1
cp %{SOURCE1} .
%pom_disable_module %{name}-maven-plugin
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin

perl -pi -e 's#org\.sonatype\.aether\.repository#org.eclipse.aether.repository#g' \
	mojo-executor/src/main/java/org/twdata/maven/mojoexecutor/MavenCompatibilityHelper.java

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE-2.0 LICENSE.txt
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE-2.0 LICENSE.txt

%changelog
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4.0:
  * Dependencies provided by Maven have been moved to the provided scope where
    possible
  * The plexus-utils dependency must remain in the compile scope due to
    MNG-6965. It has been updated to version 3.0.24 to avoid spurious security
    vulnerability notifications due to this dependency.
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 2.3.1
- Added patch:
  * mojo-executor-dependency.patch
    + Collections.emptyList() has type of  java.lang.Object and
    cannot be cast to List<Dependency>.
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Sat Nov  2 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of mojo-executor 2.3.0
